######################################
Agilent E5062A Vector Network Analyzer
######################################

.. autoclass:: pymeasure.instruments.agilent.AgilentE5062A
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.agilent.agilentE5062A.VNAChannel
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.agilent.agilentE5062A.VNATrace
    :members:
    :show-inheritance:

